==> haskell-dns-4.0.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-dns-z-dns-internal
version:              4.0.1
package-name:         dns
lib-name:             dns-internal
id:                   dns-4.0.1-4nQO16yjfMO4nVYXozKb3A-dns-internal
key:                  dns-4.0.1-4nQO16yjfMO4nVYXozKb3A-dns-internal
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  6c4e347b659562b570baa111d78d69e6
exposed-modules:
    Network.DNS.Base32Hex Network.DNS.Decode.Internal
    Network.DNS.Decode.Parsers Network.DNS.Encode.Builders
    Network.DNS.Encode.Internal Network.DNS.Imports Network.DNS.Memo
    Network.DNS.Resolver.Internal Network.DNS.StateBinary
    Network.DNS.Types.Internal Network.DNS.Types.Resolver

import-dirs:          /usr/lib/ghc-8.10.1/site-local/dns-4.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/dns-4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/dns-4.0.1
hs-libraries:         HSdns-4.0.1-4nQO16yjfMO4nVYXozKb3A-dns-internal
depends:
    array-0.5.4.0 async-2.2.2-Hz5foJOA723IkpWDnlfXlo
    attoparsec-0.13.2.4-CwM8a4WQCATLoXuAGiNv3w
    auto-update-0.1.6-Bb49RoydQAuK4XJhSXshbK base-4.14.0.0
    base16-bytestring-0.1.1.6-DS9xLNC5hoWBUNdBXU0AGB
    base64-bytestring-1.1.0.0-LUNBMkhmRjW1fHIDYumQY1
    bytestring-0.10.10.0 containers-0.6.2.1
    cryptonite-0.26-JIZdcaiOiQ0E7oAZnbqxMe
    hourglass-0.2.12-7NXnChnRUzXHuL4w3czDWY
    iproute-1.7.9-LtofSsfiYow9rqEA6eJGaE mtl-2.2.2
    network-3.1.1.1-8OGJu8k9rChLLMIzR1fXs2
    psqueues-0.2.7.2-C3rpSDlXZJtYMTk6rCt3F

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dns
version:              4.0.1
visibility:           public
id:                   dns-4.0.1-1s7lIuh9Gyx4VASmk1GqpP
key:                  dns-4.0.1-1s7lIuh9Gyx4VASmk1GqpP
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  10aa5bbdfc4036bb3caed117475c3a87
exposed:              True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils

hidden-modules:       Network.DNS.Transport
import-dirs:          /usr/lib/ghc-8.10.1/site-local/dns-4.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/dns-4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/dns-4.0.1
hs-libraries:         HSdns-4.0.1-1s7lIuh9Gyx4VASmk1GqpP
depends:
    array-0.5.4.0 async-2.2.2-Hz5foJOA723IkpWDnlfXlo
    attoparsec-0.13.2.4-CwM8a4WQCATLoXuAGiNv3w
    auto-update-0.1.6-Bb49RoydQAuK4XJhSXshbK base-4.14.0.0
    base16-bytestring-0.1.1.6-DS9xLNC5hoWBUNdBXU0AGB
    base64-bytestring-1.1.0.0-LUNBMkhmRjW1fHIDYumQY1
    bytestring-0.10.10.0 containers-0.6.2.1
    cryptonite-0.26-JIZdcaiOiQ0E7oAZnbqxMe
    dns-4.0.1-4nQO16yjfMO4nVYXozKb3A-dns-internal
    hourglass-0.2.12-7NXnChnRUzXHuL4w3czDWY
    iproute-1.7.9-LtofSsfiYow9rqEA6eJGaE mtl-2.2.2
    network-3.1.1.1-8OGJu8k9rChLLMIzR1fXs2
    psqueues-0.2.7.2-C3rpSDlXZJtYMTk6rCt3F

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-4.0.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-dns-z-dns-internal
version:              4.0.1
package-name:         dns
lib-name:             dns-internal
id:                   dns-4.0.1-7HclKpqXiMZLFED0LHDJGQ-dns-internal
key:                  dns-4.0.1-7HclKpqXiMZLFED0LHDJGQ-dns-internal
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  eddd094520a657241c25759a787cbcf9
exposed-modules:
    Network.DNS.Base32Hex Network.DNS.Decode.Internal
    Network.DNS.Decode.Parsers Network.DNS.Encode.Builders
    Network.DNS.Encode.Internal Network.DNS.Imports Network.DNS.Memo
    Network.DNS.Resolver.Internal Network.DNS.StateBinary
    Network.DNS.Types.Internal Network.DNS.Types.Resolver

import-dirs:          /usr/lib/ghc-8.10.1/site-local/dns-4.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/dns-4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/dns-4.0.1
hs-libraries:         HSdns-4.0.1-7HclKpqXiMZLFED0LHDJGQ-dns-internal
depends:
    array-0.5.4.0 async-2.2.2-Bj86P845FxLFtoqnXRki4A
    attoparsec-0.13.2.4-GOTdzZbG0wqBeikq1tq7Wl
    auto-update-0.1.6-8VwvwxXgiMJArzWVjb9n5S base-4.14.0.0
    base16-bytestring-0.1.1.6-DS9xLNC5hoWBUNdBXU0AGB
    base64-bytestring-1.1.0.0-BUHOsOVhKeC5M6ZjmSxE5I
    bytestring-0.10.10.0 containers-0.6.2.1
    cryptonite-0.26-JIZdcaiOiQ0E7oAZnbqxMe
    hourglass-0.2.12-INfCcZubLwy8n8GNFvcloA
    iproute-1.7.9-DNQm6bDiRFd5OUXbVX7ORn mtl-2.2.2
    network-3.1.1.1-D3CIp0WkhfC51dOZjHWRWc
    psqueues-0.2.7.2-Js86KYOv5mCK9ctm0RqWNn

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dns
version:              4.0.1
visibility:           public
id:                   dns-4.0.1-FWLT29s0L3C6PirIKV0wbx
key:                  dns-4.0.1-FWLT29s0L3C6PirIKV0wbx
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  e956c8d688061b3cb65843b881d3bf67
exposed:              True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils

hidden-modules:       Network.DNS.Transport
import-dirs:          /usr/lib/ghc-8.10.1/site-local/dns-4.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/dns-4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/dns-4.0.1
hs-libraries:         HSdns-4.0.1-FWLT29s0L3C6PirIKV0wbx
depends:
    array-0.5.4.0 async-2.2.2-Bj86P845FxLFtoqnXRki4A
    attoparsec-0.13.2.4-GOTdzZbG0wqBeikq1tq7Wl
    auto-update-0.1.6-8VwvwxXgiMJArzWVjb9n5S base-4.14.0.0
    base16-bytestring-0.1.1.6-DS9xLNC5hoWBUNdBXU0AGB
    base64-bytestring-1.1.0.0-BUHOsOVhKeC5M6ZjmSxE5I
    bytestring-0.10.10.0 containers-0.6.2.1
    cryptonite-0.26-JIZdcaiOiQ0E7oAZnbqxMe
    dns-4.0.1-7HclKpqXiMZLFED0LHDJGQ-dns-internal
    hourglass-0.2.12-INfCcZubLwy8n8GNFvcloA
    iproute-1.7.9-DNQm6bDiRFd5OUXbVX7ORn mtl-2.2.2
    network-3.1.1.1-D3CIp0WkhfC51dOZjHWRWc
    psqueues-0.2.7.2-Js86KYOv5mCK9ctm0RqWNn

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
